From 8a6c73e48eb36f1aab223b9b2b29dc020d8571fb Mon Sep 17 00:00:00 2001
From: Aaron LI <aly@aaronly.me>
Date: Mon, 1 Jan 2018 14:16:53 +0800
Subject: clusters/halo: Change option "tau_merger" to "time_traceback"

---
 fg21sim/configs/20-extragalactic.conf.spec | 10 +++++-----
 fg21sim/extragalactic/clusters/main.py     |  8 ++++----
 2 files changed, 9 insertions(+), 9 deletions(-)

diff --git a/fg21sim/configs/20-extragalactic.conf.spec b/fg21sim/configs/20-extragalactic.conf.spec
index 2924cf6..1992f3f 100644
--- a/fg21sim/configs/20-extragalactic.conf.spec
+++ b/fg21sim/configs/20-extragalactic.conf.spec
@@ -115,12 +115,12 @@
   # Unit: [Msun]
   merger_mass_min = float(default=1e12, min=1e10, max=1e14)
 
-  # The merger timescale, which roughly describes the duration of the
-  # merger-induced disturbance (~2-3 Gyr).  This timescale is much longer
-  # the merger crossing time (~1 Gyr), and is also longer than the lifetime
-  # of radio halos.
+  # The trace back time when to stop tracing the merging history of
+  # clusters.  ~2-3 Gyr should be enough since the turbulence acceleration
+  # effective time ~<1 Gyr and the halo lifetime is also short compared
+  # to mergers.
   # Unit: [Gyr]
-  tau_merger = float(default=2.0, min=1.0, max=5.0)
+  time_traceback = float(default=3.0, min=1.0, max=5.0)
 
   # Mass ratio of the main and sub clusters, below which is regarded as
   # a major merger event.
diff --git a/fg21sim/extragalactic/clusters/main.py b/fg21sim/extragalactic/clusters/main.py
index 57811af..a8e0576 100644
--- a/fg21sim/extragalactic/clusters/main.py
+++ b/fg21sim/extragalactic/clusters/main.py
@@ -1,4 +1,4 @@
-# Copyright (c) 2017 Weitian LI <weitian@aaronly.me>
+# Copyright (c) 2017-2018 Weitian LI <weitian@aaronly.me>
 # MIT license
 
 """
@@ -90,7 +90,7 @@ class GalaxyClusters:
         self.merger_mass_min = self.configs.getn(comp+"/merger_mass_min")
         self.ratio_major = self.configs.getn(comp+"/ratio_major")
         self.use_max_merger = self.configs.getn(comp+"/use_max_merger")
-        self.tau_merger = self.configs.getn(comp+"/tau_merger")
+        self.time_traceback = self.configs.getn(comp+"/time_traceback")
         self.frequencies = self.configs.frequencies
         self.filename_pattern = self.configs.getn("output/filename_pattern")
         self.clobber = self.configs.getn("output/clobber")
@@ -184,7 +184,7 @@ class GalaxyClusters:
         NOTE
         ----
         There may be no such recent *major* merger event satisfying the
         criteria, since we only tracing ``tau_merger`` (~2-3 Gyr) back.
         On the other hand, the cluster may only experience minor merger
         or accretion events.
 
@@ -211,7 +211,7 @@ class GalaxyClusters:
                 logger.info("[%d/%d] %.1f%% ..." % (ii, num, 100*ii/num))
             z0, M0 = row.z, row.mass
             age0 = COSMO.age(z0)
-            zmax = COSMO.redshift(age0 - self.tau_merger)
+            zmax = COSMO.redshift(age0 - self.time_traceback)
             clform = ClusterFormation(M0=M0, z0=z0, zmax=zmax,
                                       ratio_major=self.ratio_major,
                                       merger_mass_min=self.merger_mass_min)
@@ -184,7 +184,7 @@ class GalaxyClusters:
         ----
         There may be no such recent *major* merger event satisfying the
-        criteria, since we only tracing ``tau_merger`` (~2-3 Gyr) back.
+        criteria, since we only trace ``time_traceback`` (~2-3 Gyr) back.
         On the other hand, the cluster may only experience minor merger
         or accretion events.
-- 
cgit v1.2.2